%global drv_vendor Cisco
%global srcname networking_cisco
%global package_name networking-cisco
%global docpath doc/build/html

%{!?upstream_version: %global upstream_version %{version}%{?milestone}}

Name:           python-%{package_name}
Version:        2.1.1
Release:        3%{?dist}
Epoch:          1
Summary:        %{drv_vendor} OpenStack Neutron driver

License:        ASL 2.0
URL:            https://pypi.python.org/pypi/%{package_name}
Source0:	http://tarballs.openstack.org/%{package_name}/%{package_name}-%{version}.tar.gz
Source1:        neutron-cisco-cfg-agent.service
Source2:        neutron-cisco-apic-host-agent.service
Source3:        neutron-cisco-apic-service-agent.service

#patches_base=+1
Patch0001: 0001-Fixes-recent-UCSM-CI-breakage.patch
Patch0002: 0002-Make-vNIC-names-explicit-in-UCSM-plugin.patch
Patch0003: 0003-Fix-issues-with-parsing-of-some-new-single-UCSM-conf.patch
Patch0004: 0004-Nexus-threads-prematurely-terminating-sessions.patch
Patch0005: 0005-UCSM-plugin-Support-for-SP-sub-orgs-and-hostnames-wi.patch

BuildArch:      noarch
BuildRequires:  git
BuildRequires:  python2-devel
BuildRequires:  python-mock
BuildRequires:  python-neutron-tests
BuildRequires:  python-oslo-sphinx
BuildRequires:  python-pbr
BuildRequires:  python-setuptools
BuildRequires:  python-sphinx
BuildRequires:  python-testrepository
BuildRequires:  python-testtools
BuildRequires:	systemd-units

Requires:       python-babel
Requires:       python-pbr
Requires:       openstack-neutron-common
Requires:       python-UcsSdk
Requires:       python-ncclient
Requires:       python-lxml

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description
This package contains %{drv_vendor} networking driver for OpenStack Neutron.

%prep
%autosetup -n %{package_name}-%{upstream_version} -S git

# Let's handle dependencies ourseleves
rm -f requirements.txt

# Kill egg-info in order to generate new SOURCES.txt
rm -rf networking_cisco.egg-info

%build
export SKIP_PIP_INSTALL=1
%{__python2} setup.py build
%{__python2} setup.py build_sphinx
rm %{docpath}/.buildinfo

%install
export PBR_VERSION=%{version}
export SKIP_PIP_INSTALL=1
%{__python2} setup.py install --skip-build --root %{buildroot}
install -d -m 755 %{buildroot}%{_sysconfdir}/neutron/
mv %{buildroot}/usr/etc/neutron/*.ini %{buildroot}%{_sysconfdir}/neutron/
install -d -m 755 %{buildroot}%{_sysconfdir}/saf/
mv %{buildroot}/usr/etc/saf/enabler_conf.ini %{buildroot}%{_sysconfdir}/saf/

# Install systemd units
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/neutron-cisco-cfg-agent.service
install -p -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/neutron-cisco-apic-host-agent.service
install -p -D -m 644 %{SOURCE3} %{buildroot}%{_unitdir}/neutron-cisco-apic-service-agent.service
mv %{buildroot}/usr/etc/saf/init/*.service %{buildroot}%{_unitdir}

# Remove upstart files, they are not needed
rm %{buildroot}/usr/etc/saf/init/*.conf

mkdir -p %{buildroot}/%{_sysconfdir}/neutron/conf.d/neutron-cisco-cfg-agent

%files
%license LICENSE
%doc README.rst
%doc %{docpath}
%{python2_sitelib}/%{srcname}
%{python2_sitelib}/%{srcname}-%{version}-py%{python2_version}.egg-info
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/*.ini
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/saf/*.ini
%{_bindir}/neutron-cisco-cfg-agent
%{_bindir}/neutron-cisco-apic-host-agent
%{_bindir}/neutron-cisco-apic-service-agent
%{_bindir}/fabric-enabler-agent
%{_bindir}/fabric-enabler-cli
%{_bindir}/fabric-enabler-server
%{_unitdir}/neutron-cisco-cfg-agent.service
%{_unitdir}/neutron-cisco-apic-host-agent.service
%{_unitdir}/neutron-cisco-apic-service-agent.service
%{_unitdir}/fabric-enabler-agent.service
%{_unitdir}/fabric-enabler-server.service

%post
%systemd_post neutron-cisco-cfg-agent.service
%systemd_post neutron-cisco-apic-host-agent.service
%systemd_post neutron-cisco-apic-service-agent.service
%systemd_post fabric-enabler-agent.service
%systemd_post fabric-enabler-server.service

%preun
%systemd_preun neutron-cisco-cfg-agent.service
%systemd_preun neutron-cisco-apic-host-agent.service
%systemd_preun neutron-cisco-apic-service-agent.service
%systemd_preun fabric-enabler-agent.service
%systemd_preun fabric-enabler-server.service

%postun
%systemd_postun_with_restart neutron-cisco-cfg-agent.service
%systemd_postun_with_restart neutron-cisco-apic-host-agent.service
%systemd_postun_with_restart neutron-cisco-apic-service-agent.service
%systemd_postun_with_restart fabric-enabler-agent.service
%systemd_postun_with_restart fabric-enabler-server.service

%changelog
* Mon Nov 07 2016 Nir Magnezi <nmagnezi@redhat.com> 1:2.1.1-3
- UCSM plugin: Support for SP sub-orgs and hostnames with extensions, rhbz#1376073
- Nexus threads prematurely terminating sessions, rhbz#1376080

* Thu Sep 22 2016 Nir Magnezi <nmagnezi@redhat.com> 1:2.1.1-2
- Update patches_base to 1, rhbz#1376465

* Sun Sep 18 2016 Nir Magnezi <nmagnezi@redhat.com> 1:2.1.1-1
- Update to 2.1.1, rhbz#1376465

* Tue Mar 29 2016 Mike Burns <mburns@redhat.com> 1:2.0.0-3
- Replace ciscoconfparser with HTParser
- Fix issues with parsing of some new single UCSM config
- Make vNIC names explicit in UCSM plugin
- Fix latest unit test failures for Nexus py34
- Fixes recent UCSM CI breakage.
- Attribute nve_src_intf causing bad behavior
- Use public method execute() for client extension
- Change import exclusions in tox.ini and update imports
- Fix i18n imports for Liberty
- Send delete only on active Nexus switches
- Remove unused package from Nexus Driver
- Refactor Nexus test code to remove duplication
- Backport change to prevent network profile failure

* Tue Jan 19 2016 Mike Burns <mburns@redhat.com> 1:2.0.0-1
- Update to 2.0.0

* Wed Dec 02 2015 Mike Burns <mburns@redhat.com> 2015.1.0-6
- cisco nexus ML2: L3 agent HA interfaces-VLAN not created on Nexus switch.
  rhbz#1284733

* Tue Nov 10 2015 Mike Burns <mburns@redhat.com> 2015.1.0-5
- ML2 Cisco Nexus MD: VLAN/trunk config not created on all switches rhbz#1277596

* Wed Sep 16 2015 Mike Burns <mburns@redhat.com> 2015.1.0-4
- ML2 cisco_nexus MD: VLAN not created on switch rhbz#1261555

* Thu Sep 10 2015 Mike Burns <mburns@redhat.com> 2015.1.0-3
- Create knob to prevent caching ssh connection
- Bubble up exceptions when Nexus replay enabled
- Quick retry connect to resolve stale ncclient handle

* Wed Aug 26 2015 Mike Burns <mburns@redhat.com> 2015.1.0-2
- Update requirements.txt for ML2 Nexus
- Update requirements.txt
- Remove duplicate entrypoints in setup.cfg
- Cisco UCSM driver updates to handle duplicate creations
- Clean up of UCS Manager connection handle management.
- Fix Cisco CSR1KV script issues
- Replace retry count with replay failure stats
- Add scripts to enable CSR FWaaS service
- Fix N1kv trunk driver: same mac assigned to ports created
- Update netorking-cisco files for due to neutrons port dictionary subnet being replaced with a subnets list.
- ML2 cisco_nexus MD: Config hangs when replay enabled
- Move UCSM from extension drivers to mech drivers
- ML2 cisco_nexus MD: Multiprocess replay issue
- ML2 cisco_nexus MD: If configured, close ssh sessions
- Part II-Detect switch failure earlier-Port Create
- Retry count not reset on successful replay
- ML2 Nexus decomposition not complete for Nexus
- Delete fails after switch reset (replay off)
- Call to get nexus type for Nexus 9372PX fails
- Detect switch failure earlier during port create
- Enable the CSR1kv devstack plugin for Kilo
- Sanitize policy profile table on neutron restart
- Cisco Nexus1000V: Retry mechanism for VSM REST calls
- Moved N1kv section from neutron tree to stackforge
- N1Kv: Force syncing BDs on neutron restart
- s/stackforge/openstack/g
- Bump minor version number to enable development
- Sync notification to VSM & major sync refactoring
- Revert "forcing formatting of setup.cfg to match setuptools/pbr output"

* Wed Aug 05 2015 Haïkel Guémar <hguemar@fedoraproject.org> - 2015.1.0-1
- Based upon RDO delorean package, rhbz#1254153, rhbz#1230851
